# eric7.Utilities.MimeTypes

Module implementing mimetype dependent functions.

### Global Attributes

None

### Classes

None

### Functions

isTextFile | Function to test, if the given file is a text (i.e.
mimeType | Function to get the mime type of a file.

## isTextFile

isTextFile(filename)

Function to test, if the given file is a text (i.e. editable) file.

filename (str)
  name of the file to be checked

Return:
  flag indicating an editable file

Return Type:
  bool

Up

## mimeType

mimeType(filename)

Function to get the mime type of a file.

filename (str)
  name of the file to be checked

Return:
  mime type of the file

Return Type:
  str

Up